@@ -96,7 +96,7 @@ double perfunc(FUNBAG *lpdf, ENVELOPE *env, double x);
 
 void display(FILE *f, ENVELOPE *env);
 
-double u_random();
+double u_random(void);
 
 /* *********************************************************************** */
 
@@ -897,7 +897,7 @@ void display(FILE *f, ENVELOPE *env)
 
 /* *********************************************************************** */
 
-double u_random()
+double u_random(void)
 
 /* to return a standard uniform random number */
 {
